import { ActionCreator, EmptyActionCreator, EmptyProps, Props, SourceActionName, TypeFromProps } from './models';
export declare function createActionGroup<Source extends string, Actions extends Record<string, Props | EmptyProps>>(source: Source, actions: ActionGroupInput<Actions>): ActionCreatorGroup<Actions, Source>;
declare type ActionGroupInput<Actions extends Record<string, Props | EmptyProps>> = {
    [EventName in keyof Actions]: Actions[EventName] & EmptyStringCheck<EventName & string, 'event name'> & TemplateLiteralCheck<EventName & string, 'event name'> & ForbiddenCharactersCheck<EventName & string, 'event name'> & UniqueEventNameCheck<keyof Actions & string, EventName & string>;
};
declare type Join<Str extends string, Separator extends string = ' '> = Str extends `${infer First}${Separator}${infer Rest}` ? Join<`${First}${Rest}`, Separator> : Str;
declare type Trim<Str extends string> = Str extends ` ${infer S}` ? Trim<S> : Str extends `${infer S} ` ? Trim<S> : Str;
declare type TitleCase<Str extends string> = Str extends `${infer First} ${infer Rest}` ? `${Capitalize<First>} ${TitleCase<Rest>}` : Capitalize<Str>;
declare type ForbiddenCharacters = '/' | '\\' | '|' | '<' | '>' | '[' | ']' | '{' | '}' | '(' | ')' | '.' | ',' | '!' | '?' | '#' | '%' | '^' | '&' | '*' | '+' | '-' | '~' | "'" | '"' | '`';
declare type ForbiddenCharactersCheck<Str extends string, Name extends string> = Str extends `${infer _}${ForbiddenCharacters}${infer _}` ? `${Name} cannot contain ${ForbiddenCharacters}` : unknown;
declare type EmptyStringCheck<Str extends string, Name extends string> = Trim<Str> extends '' ? `${Name} cannot be an empty string or contain only spaces` : unknown;
declare type TemplateLiteralCheck<Str extends string, Name extends string> = string extends Str ? `${Name} must be a template literal type` : unknown;
declare type UniqueEventNameCheck<EventNames extends string, EventName extends string> = ActionName<EventName> extends ActionName<Exclude<EventNames, EventName>> ? `${ActionName<EventName>} action is already defined` : unknown;
declare type ActionName<EventName extends string> = Join<TitleCase<Lowercase<Trim<EventName>>>>;
declare type ActionCreatorGroup<Actions extends Record<string, Props | EmptyProps>, Source extends string> = {
    [key in keyof Actions as ActionName<key & string>]: Actions[key] extends EmptyProps ? EmptyActionCreator<SourceActionName<Source, Actions[key] & string>> : ActionCreator<SourceActionName<Source, key & string>, TypeFromProps<Actions[key]>>;
};
export {};
